@@ -10,7 +10,7 @@ class ssi_amount_if_eligible(Variable):
     reference = "https://www.law.cornell.edu/uscode/text/42/1382#b"
 
     def formula(person, period, parameters):
-        ssi = parameters(period).ssa.ssi.amount
+        ssi = parameters(period).gov.ssa.ssi.amount
         return (
             where(
                 person("ssi_claim_is_joint", period),
