@@ -4,7 +4,7 @@ from openfisca_us.model_api import *
 class in_renters_deduction(Variable):
     value_type = float
     entity = TaxUnit
-    label = "IN Renter's deductions"
+    label = "IN renter's deductions"
     unit = USD
     definition_period = YEAR
     reference = "http://iga.in.gov/legislative/laws/2021/ic/titles/006#6-3-2-6"
